@@ -213,12 +213,12 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
         elif self.tipo_objeto == TRASLADO:
             dom.setAttribute('xmlns:cfdi', 'http://www.sat.gob.mx/cfd/3')
             dom.setAttribute('xmlns:xsi', 'http://www.w3.org/2001/XMLSchema-instance')
-            dom.setAttribute('xmlns:cartaporte', 'http://www.sat.gob.mx/CartaPorte')
+            dom.setAttribute('xmlns:cartaporte20', 'http://www.sat.gob.mx/CartaPorte20')
             dom.setAttribute('xsi:schemaLocation',
                              'http://www.sat.gob.mx/cfd/3 ' +
                              'http://www.sat.gob.mx/sitio_internet/cfd/3/cfdv33.xsd ' +
-                             'http://www.sat.gob.mx/CartaPorte ' +
-                             'http://www.sat.gob.mx/sitio_internet/cfd/CartaPorte/CartaPorte.xsd')
+                             'http://www.sat.gob.mx/CartaPorte20 ' +
+                             'http://www.sat.gob.mx/sitio_internet/cfd/CartaPorte/CartaPorte20.xsd')
         else:
             dom.setAttribute('xsi:schemaLocation',
                              'http://www.sat.gob.mx/cfd/3 http://www.sat.gob.mx/sitio_internet/cfd/3/cfdv33.xsd http://www.sat.gob.mx/TimbreFiscalDigital http://www.sat.gob.mx/sitio_internet/cfd/timbrefiscaldigital/TimbreFiscalDigitalv11.xsd')
@@ -579,8 +579,8 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
 
     def get_complemento_cartaporte(self):
         try:
-            cartaporte = self.dom.createElement('cartaporte:CartaPorte')
-            cartaporte.setAttribute('Version', '1.0')
+            cartaporte = self.dom.createElement('cartaporte20:CartaPorte')
+            cartaporte.setAttribute('Version', '2.0')
             cartaporte.setAttribute('TranspInternac', self.data.get('TranspInternac'))
             if self.data.get('TranspInternac') == 'Si':
                 if self.data.get('EntradaSalidaMerc', '') not in ['Entrada', 'Salida']:
@@ -588,27 +588,39 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 cartaporte.setAttribute('EntradaSalidaMerc', self.data.get('EntradaSalidaMerc'))
                 cartaporte.setAttribute('ViaEntradaSalida', self.data.get('ViaEntradaSalida'))
 
-            cartaporte_ubicaciones = self.dom.createElement('cartaporte:Ubicaciones')
+            cartaporte_ubicaciones = self.dom.createElement('cartaporte20:Ubicaciones')
             ubicaciones = self.data.get('ubicaciones', [])
             total_distancia_recorrida = 0
             for ubicacion_data in ubicaciones:
-                cartaporte_ubicacion = self.dom.createElement('cartaporte:Ubicacion')
+                cartaporte_ubicacion = self.dom.createElement('cartaporte20:Ubicacion')
+                destination_counter = 1
                 if ubicacion_data.get('type') == 'origen':
-                    cartaporte_ubicacion_origen = self.dom.createElement('cartaporte:Origen')
-                    cartaporte_ubicacion_origen.setAttribute('RFCRemitente', ubicacion_data.get('RFCRemitente'))
-                    cartaporte_ubicacion_origen.setAttribute('NombreRemitente', ubicacion_data.get('NombreRemitente'))
-                    cartaporte_ubicacion_origen.setAttribute('FechaHoraSalida', ubicacion_data.get('FechaHoraSalida'))
-                    cartaporte_ubicacion.appendChild(cartaporte_ubicacion_origen)
+                    #cartaporte_ubicacion_origen = self.dom.createElement('cartaporte20:Origen')
+                    cartaporte_ubicacion.setAttribute('IDUbicacion', 'OR{}'.format('000001'))
+                    cartaporte_ubicacion.setAttribute('TipoUbicacion', 'Origen')
+                    cartaporte_ubicacion.setAttribute('RFCRemitenteDestinatario', ubicacion_data.get('RFCRemitente'))
+                    # cartaporte_ubicacion.setAttribute('NombreRFC', ubicacion_data.get('NombreRemitente'))
+                    cartaporte_ubicacion.setAttribute('FechaHoraSalidaLlegada', ubicacion_data.get('FechaHoraSalida'))
+                    #cartaporte_ubicacion_origen.setAttribute('RFCRemitente', ubicacion_data.get('RFCRemitente'))
+                    #cartaporte_ubicacion_origen.setAttribute('NombreRemitente', ubicacion_data.get('NombreRemitente'))
+                    #cartaporte_ubicacion_origen.setAttribute('FechaHoraSalida', ubicacion_data.get('FechaHoraSalida'))
+                    #cartaporte_ubicacion.appendChild(cartaporte_ubicacion_origen)
                 elif ubicacion_data.get('type') == 'destino':
+                    cartaporte_ubicacion.setAttribute('IDUbicacion', 'DE00000{}'.format(destination_counter))
                     cartaporte_ubicacion.setAttribute('DistanciaRecorrida', str(ubicacion_data.get('DistanciaRecorrida')))
-                    cartaporte_ubicacion_destino = self.dom.createElement('cartaporte:Destino')
-                    cartaporte_ubicacion_destino.setAttribute('RFCDestinatario', ubicacion_data.get('RFCDestinatario'))
-                    cartaporte_ubicacion_destino.setAttribute('NombreDestinatario', ubicacion_data.get('NombreDestinatario'))
-                    cartaporte_ubicacion_destino.setAttribute('FechaHoraProgLlegada', ubicacion_data.get('FechaHoraProgLlegada'))
-                    cartaporte_ubicacion.appendChild(cartaporte_ubicacion_destino)
+                    cartaporte_ubicacion.setAttribute('TipoUbicacion', 'Destino')
+                    cartaporte_ubicacion.setAttribute('RFCRemitenteDestinatario', ubicacion_data.get('RFCDestinatario'))
+                    # cartaporte_ubicacion.setAttribute('NombreRFC', ubicacion_data.get('NombreDestinatario'))
+                    cartaporte_ubicacion.setAttribute('FechaHoraSalidaLlegada', ubicacion_data.get('FechaHoraProgLlegada'))
+                    # cartaporte_ubicacion_destino = self.dom.createElement('cartaporte20:Destino')
+                    # cartaporte_ubicacion_destino.setAttribute('RFCDestinatario', ubicacion_data.get('RFCDestinatario'))
+                    # cartaporte_ubicacion_destino.setAttribute('NombreDestinatario', ubicacion_data.get('NombreDestinatario'))
+                    # cartaporte_ubicacion_destino.setAttribute('FechaHoraProgLlegada', ubicacion_data.get('FechaHoraProgLlegada'))
+                    #cartaporte_ubicacion.appendChild(cartaporte_ubicacion_destino)
                     total_distancia_recorrida += float(ubicacion_data.get('DistanciaRecorrida'))
+                    destination_counter += 1
 
-                cartaporte_ubicacion_domicilio = self.dom.createElement('cartaporte:Domicilio')
+                cartaporte_ubicacion_domicilio = self.dom.createElement('cartaporte20:Domicilio')
                 cartaporte_ubicacion_domicilio.setAttribute('Calle', ubicacion_data.get('Calle'))
                 if ubicacion_data.get('NumeroExterior') != '':
                     cartaporte_ubicacion_domicilio.setAttribute('NumeroExterior', ubicacion_data.get('NumeroExterior'))
@@ -628,41 +640,74 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
             if self.tipo_transporte in ['AutotransporteFederal', 'TransporteFerroviario']:
                 cartaporte.setAttribute('TotalDistRec', str(total_distancia_recorrida))
 
-            cartaporte_mercancias = self.dom.createElement('cartaporte:Mercancias')
+            cartaporte_mercancias = self.dom.createElement('cartaporte20:Mercancias')
             mercancias = self.data.get('mercancias', [])
             num_total_mercancias = 0
+            peso_bruto = 0
             for mercancia_data in mercancias:
-                cartaporte_mercancia = self.dom.createElement('cartaporte:Mercancia')
+                cartaporte_mercancia = self.dom.createElement('cartaporte20:Mercancia')
+                if mercancia_data.get('BienesTransp') is not None:
+                    cartaporte_mercancia.setAttribute('BienesTransp', mercancia_data.get('BienesTransp'))
+                    cartaporte_mercancia.setAttribute('Descripcion', mercancia_data.get('Descripcion'))
+                    cartaporte_mercancia.setAttribute('Cantidad', mercancia_data.get('Cantidad'))
+                    cartaporte_mercancia.setAttribute('ClaveUnidad', mercancia_data.get('ClaveUnidad'))
                 cartaporte_mercancia.setAttribute('PesoEnKg', mercancia_data.get('PesoEnKg'))
                 cartaporte_mercancia.setAttribute('ValorMercancia', mercancia_data.get('ValorMercancia'))
                 cartaporte_mercancia.setAttribute('Moneda', mercancia_data.get('Moneda'))
+                if mercancia_data.get('MaterialPeligroso') == 'Si':
+                    cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso'))
+                    cartaporte_mercancia.setAttribute('CveMaterialPeligroso', mercancia_data.get('CveMaterialPeligroso'))
+                    cartaporte_mercancia.setAttribute('Embalaje', mercancia_data.get('Embalaje'))
+                    cartaporte_mercancia.setAttribute('DescripEmbalaje', mercancia_data.get('DescripEmbalaje'))
+
                 cartaporte_mercancias.appendChild(cartaporte_mercancia)
                 num_total_mercancias += 1
+                peso_bruto += float(mercancia_data.get('PesoEnKg'))
+
+                cartaporte_mercancia_cantidad_transporta = self.dom.createElement('cartaporte20:CantidadTransporta')
+                cartaporte_mercancia_cantidad_transporta.setAttribute('Cantidad', mercancia_data.get('Cantidad'))
+                cartaporte_mercancia_cantidad_transporta.setAttribute('IDOrigen', 'OR000001')
+                cartaporte_mercancia_cantidad_transporta.setAttribute('IDDestino', 'DE000001')
+                cartaporte_mercancia.appendChild(cartaporte_mercancia_cantidad_transporta)
 
             cartaporte_mercancias.setAttribute('NumTotalMercancias', str(num_total_mercancias))
+            cartaporte_mercancias.setAttribute('PesoBrutoTotal', str(round(peso_bruto, 3)))
+            cartaporte_mercancias.setAttribute('UnidadPeso', 'KGM')
             cartaporte.appendChild(cartaporte_mercancias)
 
             if self.tipo_transporte not in ['AutotransporteFederal', 'TransporteMaritimo', 'TransporteAereo', 'TransporteFerroviario']:
                 raise Exception('Se debe registrar un tipo de transporte')
             transporte_data = self.data.get('transporte')
             if self.tipo_transporte == 'AutotransporteFederal':
-                cartaporte_tipo_transporte = self.dom.createElement('cartaporte:AutotransporteFederal')
+                cartaporte_tipo_transporte = self.dom.createElement('cartaporte20:Autotransporte')
                 cartaporte_tipo_transporte.setAttribute('PermSCT', transporte_data.get('PermSCT'))
                 cartaporte_tipo_transporte.setAttribute('NumPermisoSCT', transporte_data.get('NumPermisoSCT'))
-                cartaporte_tipo_transporte.setAttribute('NombreAseg', transporte_data.get('NombreAseg'))
-                cartaporte_tipo_transporte.setAttribute('NumPolizaSeguro', transporte_data.get('NumPolizaSeguro'))
+                # cartaporte_tipo_transporte.setAttribute('NombreAseg', transporte_data.get('NombreAseg'))
+                # cartaporte_tipo_transporte.setAttribute('NumPolizaSeguro', transporte_data.get('NumPolizaSeguro'))
 
-                cartaporte_identificacion_vehicular = self.dom.createElement('cartaporte:IdentificacionVehicular')
+                cartaporte_identificacion_vehicular = self.dom.createElement('cartaporte20:IdentificacionVehicular')
                 cartaporte_identificacion_vehicular.setAttribute('ConfigVehicular', transporte_data.get('ConfigVehicular'))
                 cartaporte_identificacion_vehicular.setAttribute('PlacaVM', transporte_data.get('PlacaVM'))
                 cartaporte_identificacion_vehicular.setAttribute('AnioModeloVM', transporte_data.get('AnioModeloVM'))
                 cartaporte_tipo_transporte.appendChild(cartaporte_identificacion_vehicular)
 
+
+                cartaporte_seguros = self.dom.createElement('cartaporte20:Seguros')
+                cartaporte_seguros.setAttribute('AseguraRespCivil', transporte_data.get('NombreAseg'))
+                cartaporte_seguros.setAttribute('AseguraMedAmbiente', transporte_data.get('NombreAseg'))
+                cartaporte_seguros.setAttribute('AseguraCarga', transporte_data.get('NombreAseg'))
+                cartaporte_seguros.setAttribute('PolizaCarga', transporte_data.get('NumPolizaSeguro'))
+                cartaporte_seguros.setAttribute('PolizaMedAmbiente', transporte_data.get('NumPolizaSeguro'))
+                cartaporte_seguros.setAttribute('PolizaRespCivil', transporte_data.get('NumPolizaSeguro'))
+                cartaporte_seguros.setAttribute('PrimaSeguro', '1000')
+
+                cartaporte_tipo_transporte.appendChild(cartaporte_seguros)
+
                 remolques = transporte_data.get('remolques', [])
                 if len(remolques) > 0:
-                    cartaporte_remolques = self.dom.createElement('cartaporte:Remolques')
+                    cartaporte_remolques = self.dom.createElement('cartaporte20:Remolques')
                     for remolque_data in remolques:
-                        cartaporte_remolque = self.dom.createElement('cartaporte:Remolque')
+                        cartaporte_remolque = self.dom.createElement('cartaporte20:Remolque')
                         cartaporte_remolque.setAttribute('SubTipoRem', remolque_data.get('SubTipoRem'))
                         cartaporte_remolque.setAttribute('Placa', remolque_data.get('Placa'))
                         cartaporte_remolques.appendChild(cartaporte_remolque)
@@ -670,37 +715,43 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
 
                 cartaporte_mercancias.appendChild(cartaporte_tipo_transporte)
 
-            cartaporte_figura_transporte = self.dom.createElement('cartaporte:FiguraTransporte')
-            cartaporte_figura_transporte.setAttribute('CveTransporte', transporte_data.get('CveTransporte'))
+            cartaporte_figura_transporte = self.dom.createElement('cartaporte20:FiguraTransporte')
+            # cartaporte_figura_transporte.setAttribute('CveTransporte', transporte_data.get('CveTransporte'))
 
             operadores = transporte_data.get('operadores', [])
-            cartaporte_operadores = self.dom.createElement('cartaporte:Operadores')
+            # cartaporte_operadores = self.dom.createElement('cartaporte20:Operadores')
             for operador_data in operadores:
-                cartaporte_operador = self.dom.createElement('cartaporte:Operador')
-                cartaporte_operador.setAttribute('RFCOperador', operador_data.get('RFCOperador'))
+                # cartaporte_operador = self.dom.createElement('cartaporte20:Operador')
+                # cartaporte_operador.setAttribute('RFCOperador', operador_data.get('RFCOperador'))
+                # cartaporte_operador.setAttribute('NumLicencia', operador_data.get('NumLicencia'))
+                # cartaporte_operador.setAttribute('NombreOperador', operador_data.get('NombreOperador'))
+
+                cartaporte_operador = self.dom.createElement('cartaporte20:TiposFigura')
+                cartaporte_operador.setAttribute('TipoFigura', '01')
+                cartaporte_operador.setAttribute('RFCFigura', operador_data.get('RFCOperador'))
                 cartaporte_operador.setAttribute('NumLicencia', operador_data.get('NumLicencia'))
-                cartaporte_operador.setAttribute('NombreOperador', operador_data.get('NombreOperador'))
 
-                if operador_data.get('Calle', '') != '':
-                    cartaporte_operador_domicilio = self.dom.createElement('cartaporte:Domicilio')
-                    cartaporte_operador_domicilio.setAttribute('Calle', operador_data.get('Calle'))
-                    if operador_data.get('NumeroExterior', '') != '':
-                        cartaporte_operador_domicilio.setAttribute('NumeroExterior', operador_data.get('NumeroExterior'))
-                    if operador_data.get('Colonia', '') != '':
-                        cartaporte_operador_domicilio.setAttribute('Colonia', operador_data.get('Colonia'))
-                    cartaporte_operador_domicilio.setAttribute('Localidad', operador_data.get('Localidad'))
-                    if operador_data.get('Referencia', '') != '':
-                        cartaporte_operador_domicilio.setAttribute('Referencia', operador_data.get('Referencia'))
-                    cartaporte_operador_domicilio.setAttribute('Municipio', operador_data.get('Municipio'))
-                    cartaporte_operador_domicilio.setAttribute('Estado', operador_data.get('Estado'))
-                    cartaporte_operador_domicilio.setAttribute('Pais', operador_data.get('Pais'))
-                    cartaporte_operador_domicilio.setAttribute('CodigoPostal', operador_data.get('CodigoPostal'))
-                    cartaporte_operador.appendChild(cartaporte_operador_domicilio)
+                # if operador_data.get('Calle', '') != '':
+                #     cartaporte_operador_domicilio = self.dom.createElement('cartaporte20:Domicilio')
+                #     cartaporte_operador_domicilio.setAttribute('Calle', operador_data.get('Calle'))
+                #     if operador_data.get('NumeroExterior', '') != '':
+                #         cartaporte_operador_domicilio.setAttribute('NumeroExterior', operador_data.get('NumeroExterior'))
+                #     if operador_data.get('Colonia', '') != '':
+                #         cartaporte_operador_domicilio.setAttribute('Colonia', operador_data.get('Colonia'))
+                #     cartaporte_operador_domicilio.setAttribute('Localidad', operador_data.get('Localidad'))
+                #     if operador_data.get('Referencia', '') != '':
+                #         cartaporte_operador_domicilio.setAttribute('Referencia', operador_data.get('Referencia'))
+                #     cartaporte_operador_domicilio.setAttribute('Municipio', operador_data.get('Municipio'))
+                #     cartaporte_operador_domicilio.setAttribute('Estado', operador_data.get('Estado'))
+                #     cartaporte_operador_domicilio.setAttribute('Pais', operador_data.get('Pais'))
+                #     cartaporte_operador_domicilio.setAttribute('CodigoPostal', operador_data.get('CodigoPostal'))
+                #     cartaporte_operador.appendChild(cartaporte_operador_domicilio)
 
-                cartaporte_operadores.appendChild(cartaporte_operador)
-            cartaporte_figura_transporte.appendChild(cartaporte_operadores)
+                # cartaporte_operadores.appendChild(cartaporte_operador)
+            # cartaporte_figura_transporte.appendChild(cartaporte_operadores)
+            cartaporte_figura_transporte.appendChild(cartaporte_operador)
             cartaporte.appendChild(cartaporte_figura_transporte)
 
             return cartaporte
         except Exception as e:
-            raise Exception("Ocurrio un error al generar el complemento cartaporte. Error::: " + str(e))
+            raise Exception("Ocurrio un error al generar el complemento cartaporte. Error::: " + str(e))
\ No newline at end of file
